<?php
$translations = array(
	'General_Locale' => 'eu_ES.UTF-8',
	'General_TranslatorName' => 'Librezale.org',
	'General_TranslatorEmail' => 'librezale@librezale.org',
	'General_EnglishLanguageName' => 'Basque',
	'General_OriginalLanguageName' => 'Euskara',
	'General_HelloUser' => 'Kaixo %s!',
	'General_OpenSourceWebAnalytics' => 'Kode irekiko web analitikak',
	'General_Dashboard' => 'Arbela',
	'General_DashboardForASpecificWebsite' => 'Webgune jakin baterako arbela',
	'General_MultiSitesSummary' => 'Webgune guztiak',
	'General_AllWebsitesDashboard' => 'Webgune guztien arbela',
	'General_API' => 'APIa',
	'General_Widgets' => 'Widget-ak',
	'General_Settings' => 'Ezarpenak',
	'General_GiveUsYourFeedback' => 'Emaiguzu zure iritzia!',
	'General_Unknown' => 'Ezezaguna',
	'General_Required' => '%s behar da',
	'General_NotValid' => '%s ez da baliozkoa',
	'General_Error' => 'Errorea',
	'General_Warning' => 'Abisua',
	'General_BackToHomepage' => 'Atzera Piwik hasiera-orrira',
	'General_Yes' => 'Bai',
	'General_No' => 'Ez',
	'General_Delete' => 'Ezabatu',
	'General_Report' => 'Txostena',
	'General_Edit' => 'Editatu',
	'General_Download' => 'Deskargatu',
	'General_Ok' => 'Ados',
	'General_Close' => 'Itxi',
	'General_OrCancel' => 'edo %s utzi %s',
	'General_Logout' => 'Amaitu saioa',
	'General_Username' => 'Erabiltzaile-izena',
	'General_Description' => 'Azalpena',
	'General_Done' => 'Eginda',
	'General_Name' => 'Izena',
	'General_Value' => 'Balioa',
	'General_Details' => 'Xehetasunak',
	'General_Default' => 'Lehenetsia',
	'General_Date' => 'Data',
	'General_Period' => 'Tartea',
	'General_Today' => 'Gaur',
	'General_Yesterday' => 'Atzo',
	'General_CurrentWeek' => 'Aste hau',
	'General_CurrentMonth' => 'Hilabete hau',
	'General_CurrentYear' => 'Urte hau',
	'General_DateRange' => 'Data tartea:',
	'General_LoadingData' => 'Datuak kargatzen...',
	'General_Loading_js' => 'Kargatzen...',
	'General_GoTo' => 'Joan %s(e)ra',
	'General_Next' => 'Hurrengoa',
	'General_Previous' => 'Aurrekoa',
	'General_Search' => 'Bilatu',
	'General_Others' => 'Besteak',
	'General_Table' => 'Taula',
	'General_Piechart' => 'Tarta-diagrama',
	'General_TagCloud' => 'Etiketa-hodeia',
	'General_VBarGraph' => 'Barra-diagrama bertikala',
	'General_SaveImageOnYourComputer_js' => 'Irudia zure ordenagailuan gordetzeko, egin eskuin-klika irudian eta hautatu "Gorde irudia honela..."',
	'General_Refresh' => 'Berritu orria',
	'General_Visitors' => 'Bisitariak',
	'General_ExportThisReport' => 'Esportatu datu multzoa beste formatutan',
	'General_ExportAsImage_js' => 'Esportatu irudi gisa',
	'General_Export' => 'Esportatu',
	'General_YourChangesHaveBeenSaved' => 'Zure aldaketak gorde egin dira.',
	'General_ErrorRequest' => 'Kontxo… arazoa egon da eskaeran, saiatu berriro mesedez.',
	'General_ColumnNbUniqVisitors' => 'Bisitari desberdinak',
	'General_ColumnNbVisits' => 'Bisitak',
	'General_ColumnPercentageVisits' => '%s bisita',
	'General_ColumnNbActions' => 'Ekintzak',
	'General_ColumnMaxActions' => 'Bisita bateko gehienezko ekintzak',
	'General_ColumnSumVisitLength' => 'Bisitariek guztira igarotako denbora (segundotan)',
	'General_ColumnLabel' => 'Etiketa',
	'General_ColumnConversionRate' => 'Bihurketa-tasa',
	'General_ColumnActionsPerVisit' => 'Ekintzak bisitako',
	'General_VisitDuration' => 'B.b.ko bisiten iraupena (segundotan)',
	'General_ColumnAvgTimeOnSite' => 'B.b.ko denbora webgunean',
	'General_ColumnBounceRate' => 'Errebotatze-tasa',
	'General_ColumnExitRate' => 'Irteera-tasa',
	'General_ColumnPageviews' => 'Orri-bistaratzeak',
	'General_ColumnUniquePageviews' => 'Orri-bistaratze desberdinak',
	'General_ColumnBounces' => 'Erreboteak',
	'General_ColumnEntrances' => 'Sarrerak',
	'General_ColumnExits' => 'Irteerak',
	'General_ColumnAverageTimeOnPage' => 'B.b.ko denbora orrialdean',
	'General_ColumnValuePerVisit' => 'Balioa bisitako',
	'General_ColumnVisitsWithConversions' => 'Bihurketak dituzten bisitak',
	'General_YearsDays' => '%1$s urte %2$s egun',
	'General_DaysHours' => '%1$s egun %2$s ordu',
	'General_HoursMinutes' => '%1$s ordu %2$s min',
	'General_MinutesSeconds' => '%1$s min %2$s s',
	'General_Seconds' => '%ss',
	'General_Save' => 'Gorde',
	'General_ForExampleShort' => 'adib.',
	'General_YouMustBeLoggedIn' => 'Saioa hasi behar duzu funtzionaltasun hau erabiltzeko.',
	'General_Website' => 'Webgunea',
	'General_GeneralSettings' => 'Ezarpen orokorrak',
	'General_NSeconds' => '%s segundo',
	'General_RequiresFlash' => 'Piwik-en grafikoak bistaratzeko Flash behar da',
	'General_GraphHelp' => 'Piwik-en grafikoak bistaratzeko informazio gehiago.',
	'General_NoDataForTagCloud' => 'Daturik ez etiketa-hodei honentzat.',
	'General_DisplaySimpleTable' => 'Bistaratu taula sinplea',
	'General_DisplayTableWithMoreMetrics' => 'Bistaratu taula estatistika gehiagorekin',
	'General_DisplayTableWithGoalMetrics' => 'Bistaratu taula helburuen estatistikekin',
	'General_YouAreViewingDemoShortMessage' => 'Piwiken demoa ikusten ari zara',
	'General_NewUpdatePiwikX' => 'Eguneraketa berria: Piwik %s',
	'General_AboutPiwikX' => 'Piwik %s(r)i buruz',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %1$s eskura dago. %2$s Eguneratu orain!%3$s (ikusi %4$s aldaketak%5$s).',
	'General_PiwikXIsAvailablePleaseNotifyPiwikAdmin' => '%s eskura dago. Mesedez jakinarazi gunearen kudeatzaileari.',
	'General_BackToPiwik' => 'Itzuli Piwik-era',
	'General_ShortMonth_1' => 'urt',
	'General_ShortMonth_2' => 'ots',
	'General_ShortMonth_3' => 'mar',
	'General_ShortMonth_4' => 'api',
	'General_ShortMonth_5' => 'mai',
	'General_ShortMonth_6' => 'eka',
	'General_ShortMonth_7' => 'uzt',
	'General_ShortMonth_8' => 'abu',
	'General_ShortMonth_9' => 'ira',
	'General_ShortMonth_10' => 'urr',
	'General_ShortMonth_11' => 'aza',
	'General_ShortMonth_12' => 'abe',
	'General_LongMonth_1' => 'urtarrila',
	'General_LongMonth_2' => 'otsaila',
	'General_LongMonth_3' => 'martxoa',
	'General_LongMonth_4' => 'apirila',
	'General_LongMonth_5' => 'maiatza',
	'General_LongMonth_6' => 'ekaina',
	'General_LongMonth_7' => 'uztaila',
	'General_LongMonth_8' => 'abuztua',
	'General_LongMonth_9' => 'iraila',
	'General_LongMonth_10' => 'urria',
	'General_LongMonth_11' => 'azaroa',
	'General_LongMonth_12' => 'abendua',
	'General_ShortDay_1' => 'al.',
	'General_ShortDay_2' => 'ar.',
	'General_ShortDay_3' => 'az.',
	'General_ShortDay_4' => 'og.',
	'General_ShortDay_5' => 'ol.',
	'General_ShortDay_6' => 'lr.',
	'General_ShortDay_7' => 'ig.',
	'General_LongDay_1' => 'astelehena',
	'General_LongDay_2' => 'asteartea',
	'General_LongDay_3' => 'asteazkena',
	'General_LongDay_4' => 'osteguna',
	'General_LongDay_5' => 'ostirala',
	'General_LongDay_6' => 'larunbata',
	'General_LongDay_7' => 'igandea',
	'General_Daily' => 'Egunero',
	'General_Weekly' => 'Astero',
	'General_Monthly' => 'Hilero',
	'General_ExceptionDatabaseVersion' => 'Zure %1$s bertsioa %2$s da baina Piwik-ek gutxienez %3$s behar du.',
	'General_ExceptionMissingFile' => 'Fitxategia falta da: %s',
	'General_ExceptionFilesizeMismatch' => 'Fitxategien tamainak ez datoz bat: %1$s (esperotako luzera: %2$s, aurkitua: %3$s)',
	'General_ExceptionFileIntegrity' => 'Osotasun egiaztapenak huts egin du: %s',
	'General_ExceptionNonceMismatch' => 'Ezin da segurtasun-tokena egiaztatu inprimaki honetan.',
	'General_PleaseSpecifyValue' => 'Mesedez zehaztu balioa \'%s\'(r)entzat.',
	'General_ExceptionMethodNotFound' => '\'%s\' metodoa ez dago edo ez dago eskura \'%s\' moduluan.',
	'General_ExceptionUndeletableFile' => 'Ezin da %s ezabatu',
	'General_ExceptionConfigurationFileNotFound' => '{%s} konfigurazio-fitxategia ez da aurkitu.',
	'General_ExceptionInvalidToken' => 'Tokena baliogabea da.',
	'General_UseSMTPServerForEmail' => 'Erabili SMTP zerbitzaria e-postarako',
	'General_SmtpServerAddress' => 'SMT zerbitzariaren helbidea',
	'General_SmtpPort' => 'SMTP ataka',
	'General_AuthenticationMethodSmtp' => 'SMTPrako autentifikazio metodoa',
	'General_SmtpUsername' => 'SMTP erabiltzaile-izena',
	'General_SmtpPassword' => 'SMTP pasahitza',
	'General_OnlyEnterIfRequired' => 'Idatzi erabiltzaile-izena soilik zure SMTP zerbitzariak behar badu',
	'General_OnlyEnterIfRequiredPassword' => 'Idatzi pasahitza soilik zure SMTP zerbitzariak behar badu',
	'General_InvalidResponse' => 'Jasotako datuak baliogabeak dira.',
	'General_ChooseLanguage' => 'Aukeratu hizkuntza',
	'General_ChoosePeriod' => 'Aukeratu aldia',
	'General_ChooseWebsite' => 'Aukeratu webgunea',
	'General_Language' => 'Hizkuntza',
	'General_PleaseUpdatePiwik' => 'Mesedez eguneratu zure Piwik',
	'General_RequestTimedOut' => '%s(r)a egindako datu-eskaera denboraz kanpo geratu da. Saiatu berriro mesedez.',
	'Actions_Actions' => 'Ekintzak',
	'Actions_SubmenuPages' => 'Orriak',
	'Actions_SubmenuPageTitles' => 'Orrien izenburuak',
	'Actions_SubmenuOutlinks' => 'Kanpo-loturak',
	'Actions_SubmenuDownloads' => 'Deskargak',
	'Actions_ColumnClicks' => 'Klikak',
	'Actions_ColumnUniqueClicks' => 'Klik desberdinak',
	'Actions_ColumnDownloads' => 'Deskargak',
	'Actions_ColumnUniqueDownloads' => 'Deskarga desberdinak',
	'Actions_ColumnPageName' => 'Orriaren izena',
	'Actions_ColumnPageURL' => 'Orriaren URLa',
	'Actions_ColumnClickedURL' => 'Klik egindako URLa',
	'Actions_ColumnDownloadURL' => 'Deskargaren URLa',
	'API_LoadedAPIs' => '%s API ondo kargatu dira',
	'CoreHome_JavascriptDisabled' => 'JavaScript-ek gaituta egon behar du Piwik ikuspegi estandarrean erabiltzeko.<br />Badirudi ordea JavaScript desgaituta dagoela edo zure nabigatzaileak ez duela onartzen.<br />Ikuspegi estandarra erabiltzeako, gaitu JavaScript zure nabigatzailearen aukeretan eta ondoren %1$ssaiatu berriro%2$s.<br />',
	'CoreHome_CategoryNoData' => 'Daturik ez kategoria honetan. Saiatu "Sartu populazio guztia" aukerarekin.',
	'CoreHome_ShowJSCode' => 'Erakutsi txertatu beharreko JavaScript kodea',
	'CoreHome_PageOf_js' => '%1$s / %2$s',
	'CoreHome_PeriodDay' => 'Eguna',
	'CoreHome_PeriodWeek' => 'Astea',
	'CoreHome_PeriodMonth' => 'Hilabetea',
	'CoreHome_PeriodYear' => 'Urtea',
	'CoreHome_PeriodDays' => 'egun',
	'CoreHome_PeriodWeeks' => 'aste',
	'CoreHome_PeriodMonths' => 'hilabete',
	'CoreHome_PeriodYears' => 'urte',
	'General_DaySu_js' => 'ig',
	'General_DayMo_js' => 'al',
	'General_DayTu_js' => 'ar',
	'General_DayWe_js' => 'az',
	'General_DayTh_js' => 'og',
	'General_DayFr_js' => 'ol',
	'General_DaySa_js' => 'lr',
	'General_ShortDay_1_js' => 'ig.',
	'General_ShortDay_2_js' => 'al.',
	'General_ShortDay_3_js' => 'ar.',
	'General_ShortDay_4_js' => 'az.',
	'General_ShortDay_5_js' => 'og.',
	'General_ShortDay_6_js' => 'ol.',
	'General_ShortDay_7_js' => 'lr.',
	'General_LongDay_1_js' => 'igandea',
	'General_LongDay_2_js' => 'astelehena',
	'General_LongDay_3_js' => 'asteartea',
	'General_LongDay_4_js' => 'asteazkena',
	'General_LongDay_5_js' => 'osteguna',
	'General_LongDay_6_js' => 'ostirala',
	'General_LongDay_7_js' => 'larunbata',
	'General_ShortMonth_1_js' => 'urtj',
	'General_ShortMonth_2_js' => 'ots',
	'General_ShortMonth_3_js' => 'mar',
	'General_ShortMonth_4_js' => 'api',
	'General_ShortMonth_5_js' => 'mai',
	'General_ShortMonth_6_js' => 'eka',
	'General_ShortMonth_7_js' => 'uzt',
	'General_ShortMonth_8_js' => 'abu',
	'General_ShortMonth_9_js' => 'ira',
	'General_ShortMonth_10_js' => 'urr',
	'General_ShortMonth_11_js' => 'aza',
	'General_ShortMonth_12_js' => 'abe',
	'General_MonthJanuary_js' => 'urtarrila',
	'General_MonthFebruary_js' => 'otsaila',
	'General_MonthMarch_js' => 'martxoa',
	'General_MonthApril_js' => 'apirila',
	'General_MonthMay_js' => 'maiatza',
	'General_MonthJune_js' => 'ekaina',
	'General_MonthJuly_js' => 'uztaila',
	'General_MonthAugust_js' => 'abuztua',
	'General_MonthSeptember_js' => 'iraila',
	'General_MonthOctober_js' => 'urria',
	'General_MonthNovember_js' => 'azaroa',
	'General_MonthDecember_js' => 'abendua',
	'CorePluginsAdmin_Plugins' => 'Pluginak',
	'CorePluginsAdmin_PluginsManagement' => 'Pluginen kudeaketa',
	'CorePluginsAdmin_MainDescription' => 'Piwik-en funtzionaltasunak hedatu eta zabaltzen dituzte pluginek. Plugin bat instalatu ondoren, hemendik gaitu edo ezgaitu dezakezu.',
	'CorePluginsAdmin_Plugin' => 'Plugina',
	'CorePluginsAdmin_Version' => 'Bertsioa',
	'CorePluginsAdmin_Status' => 'Egoera',
	'CorePluginsAdmin_Action' => 'Ekintza',
	'CorePluginsAdmin_PluginHomepage' => 'Pluginaren hasiera-orria',
	'CorePluginsAdmin_Activated' => 'Gaituta',
	'CorePluginsAdmin_Active' => 'Gaituta',
	'CorePluginsAdmin_Inactive' => 'Ezgaituta',
	'CorePluginsAdmin_Deactivate' => 'Ezgaitu',
	'CorePluginsAdmin_Activate' => 'Gaitu',
	'CorePluginsAdmin_MenuPlugins' => 'Pluginak',
	'CoreUpdater_UpdateTitle' => 'Eguneratu',
	'CoreUpdater_DatabaseUpgradeRequired' => 'Datu-basearen bertsio-berritzea beharrezkoa',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Zure Piwik datu-basea zaharkituta dago eta jarraitu aurretik bertsio-berritu behar da.',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'Piwik datu-basea %1$s bertsiotik %2$s bertsio berrira bertsio-berrituko da.',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'Ondorengo pluginak eguneratuko dira: %s.',
	'CoreUpdater_TheUpgradeProcessMayFailExecuteCommand' => 'Piwik datu-base handia badaukazu, eguneraketek oso luze jo dezakete nabigatzailean exekutatuta. Egoera honetan komando-lerrotik exekuta ditzakezu eguneraketak: %s',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'Datu-basea bertsio-berritzeko prozesuak denbora bat har lezake, izan pazientzia beraz.',
	'CoreUpdater_UpgradePiwik' => 'Bertsio-berritu Piwik',
	'CoreUpdater_ErrorDIYHelp' => 'Erabiltzaile aurreratua bazara eta datu-basearen bertsio-berritzean errore bat aurkitzen baduzu:',
	'CoreUpdater_ErrorDIYHelp_1' => 'identifikatu eta zuzendu arazoaren iturburua (adibidez, memory_limit edo max_execution_time)',
	'CoreUpdater_ErrorDIYHelp_2' => 'exekutatu falta diren galderak huts egin duen eguneraketan',
	'CoreUpdater_ErrorDIYHelp_3' => 'eguneratu eskuz zure Piwik datu-baseko `option` taula, version_core-ren balioa huts egin duen eguneraketara ezarriz',
	'CoreUpdater_ErrorDIYHelp_4' => 'exekutatu berriro eguneratzailea (nabigatzailearen bidez edo komando-lerrotik) falta diren eguneraketekin jarraitzeko',
	'CoreUpdater_ErrorDIYHelp_5' => 'eman arazoaren (eta soluzioaren) berri, Piwik hobetu dadin',
	'CoreUpdater_HelpMessageContent' => 'Emaiozu begirada %1$s Piwik FAQari %2$s, zeinak eguneraketetan gerta litezkeen ohiko erroreak azaltzen dituen. %3$s Galdeiozu zure sistemaren kudeatzaileari - ziurrenik laguntzeko moduan izango da, errorea zerbitzariarekin edo MySQLren konfigurazioari lotuta egon baitaiteke.',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Errore kritikoa eguneraketa prozesuan:',
	'CoreUpdater_HelpMessageIntroductionWhenError' => 'Goikoa muinare errore-mezua da. Arrazoia azaltzen lagun lezake, baina laguntza gehiago behar izanez gero:',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'Eguneraketa ondo burutu da, baina arazoak egon dira prozesuan zehar. Mesedez irakur ezazu goiko azalpenak xehetasun gehiagorako. Laguntza gehiago jasotzeko:',
	'CoreUpdater_UpgradeComplete' => 'Bertsio-berritzea burututa!',
	'CoreUpdater_WarningMessages' => 'Abisuak:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'Errorea pluginak eguneratzean:',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'Ondorengo pluginak automatikoki ezgaitu ditugu: %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik ondo eguneratu da!',
	'CoreUpdater_ContinueToPiwik' => 'Jarraitu Piwik-era',
	'CoreUpdater_UpdateAutomatically' => 'Eguneratu automatikoki',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'Piwik-en bertsio berria eskura dago eguneratzeko',
	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => '%s bertsiora automatikoi egunera dezakezu edo paketea deskargatu eta eskuz instalatu:',
	'CoreUpdater_DownloadX' => 'Deskargatu %s',
	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'Piwik-en klik bakarreko eguneraketa utzi egin da. Goiko errore-mezua ezin baduzu konpondu, Piwik eskuz eguneratzea gomendatzen da. %1$s Emaiozu begirada bat %2$seguneraketen dokumentazioari%3$s konponbidea bilatzeko!',
	'CoreUpdater_DownloadingUpdateFromX' => 'Eguneraketa deskargatzen: %s',
	'CoreUpdater_UnpackingTheUpdate' => 'Eguneraketa despaketatzen',
	'CoreUpdater_VerifyingUnpackedFiles' => 'Despaketatutako fitxategiak egiaztatzen',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Konfigurazio-fitxategiaren babeskopia sortzen %s kokalekuan',
	'CoreUpdater_InstallingTheLatestVersion' => 'Azkenengo bertsioa instalatzen',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik ondo eguneratu da!',
	'CoreUpdater_EmptyDatabaseError' => '%s datu-basea hutsik dago. Zure Piwik konfigurazio-fitxategi editatu edo ezabatu behar duzu.',
	'CoreUpdater_ExceptionAlreadyLatestVersion' => 'Zure Piwik %s bertsioa eguneratuta dago.',
	'CoreUpdater_ExceptionArchiveIncompatible' => 'Artxibo bateraezina: %s',
	'CoreUpdater_ExceptionArchiveEmpty' => 'Artxibo hutsa.',
	'CoreUpdater_ExceptionArchiveIncomplete' => 'Artxiboa osatu gabe dago: fitxategi batzuk falta dira (adib. %s).',
	'Dashboard_Dashboard' => 'Arbela',
	'Dashboard_DeleteWidgetConfirm' => 'Ziur zaude widget hau arbeletik ezabatu nahi duzula?',
	'Dashboard_SelectWidget' => 'Hautatu arbelean gehitzeko widget-a',
	'Dashboard_AddPreviewedWidget_js' => 'Gehitu arbelean aurrebistako widget-a',
	'Dashboard_WidgetPreview_js' => 'Widget-aren aurrebista',
	'Dashboard_Close_js' => 'Itxi',
	'Dashboard_TitleWidgetInDashboard_js' => 'Widget-a arbelan dago',
	'Dashboard_TitleClickToAdd_js' => 'Egin klik arbelean gehitzeko',
	'Dashboard_LoadingWidget_js' => 'Widget-a kargatzen, itxaron mesedez...',
	'Dashboard_WidgetNotFound_js' => 'Ez da widget-a aurkitu',
	'DBStats_DatabaseUsage' => 'Datu-basearen erabilera',
	'DBStats_MainDescription' => 'Zure web analitiken datu guztiak MySQL datu-basean biltegiratzen ari da Piwik. Une honetan Piwik-en taulek tamaina hau hartzen dute: %s.',
	'DBStats_LearnMore' => 'Piwik-ek datuak nola prozesatzen dituen eta Piwik trafiko ertain eta handikjo webguneetarako nola moldatu jakiteko, emaiozu begirada dokumentazioari: %s.',
	'DBStats_Table' => 'Taula',
	'DBStats_RowCount' => 'Errenkada kopurua',
	'DBStats_DataSize' => 'Datuen tamaina',
	'DBStats_IndexSize' => 'Indizearen tamaina',
	'DBStats_TotalSize' => 'Tamaina osoa',
	'Goals_Goals' => 'Helburuak',
	'Goals_GoalsOverview' => 'Helburuen ikuspegi orokorra',
	'Goals_GoalsManagement' => 'Helburuen kudeaketa',
	'Goals_ColumnConversions' => 'Bihurketa',
	'Goals_ColumnRevenue' => 'Etekina',
	'Goals_GoalX' => '%s helburua',
	'Goals_AddNewGoal' => 'Gehitu helburu berria',
	'Goals_AddNewGoalOrEditExistingGoal' => '%sGehitu helburu berria%s edo %sEditatu%s dauden helburuak',
	'Goals_AddGoal_js' => 'Gehitu helburua',
	'Goals_UpdateGoal_js' => 'Eguneratu helburua',
	'Goals_DeleteGoalConfirm_js' => 'Ziur zaude %s helburua ezabatu nahi duzula?',
	'Goals_CreateNewGOal' => 'Sortu helburu berria',
	'Goals_ViewAndEditGoals' => 'Ikusi eta editatu helburuak',
	'Goals_GoalName' => 'Helburu-izena',
	'Goals_URL' => 'URLa',
	'Goals_Filename' => 'fitxategi-izena',
	'Goals_ExternalWebsiteUrl' => 'kanpoko webgunearen URLa',
	'Goals_Download' => 'Deskargatu fitxategia',
	'Goals_ClickOutlink' => 'Egin klik kanpoko webgune baterako loturan',
	'Goals_Optional' => '(aukerazkoa)',
	'Goals_ConversionsOverview' => 'Bihurketen ikuspegi orokorra',
	'Goals_Pattern' => 'Eredua',
	'Installation_Installation' => 'Instalazioa',
	'Installation_InstallationStatus' => 'Instalazioaren egoera',
	'Installation_PercentDone' => '%% %s eginda',
	'Installation_NoConfigFound' => 'Piwik konfigurazio-fitxategia ezin izan da aurkitu eta Piwik orri bat atzitzen saiatzen ari zara.<br /><b>  » <a href=\'index.php\'>Piwik orain instalatu</a> dezakezu</b><br /><small>Aurretik Piwik instalatu eta datu-basean taulak badituzu, ez kezkatu, taula berdinak berrerabil ditzakezu eta dauden datuak mantendu!</small>',
	'Installation_DatabaseSetup' => 'Datu-basearen konfigurazioa',
	'Installation_DatabaseSetupServer' => 'datu-basearen zerbitzaria',
	'Installation_DatabaseSetupLogin' => 'erabiltzaile-izena',
	'Installation_DatabaseSetupPassword' => 'pasahitza',
	'Installation_DatabaseSetupDatabaseName' => 'datu-basearen izena',
	'Installation_DatabaseSetupTablePrefix' => 'taularen aurrizkia',
	'Installation_DatabaseSetupAdapter' => 'egokitzailea',
	'Installation_DatabaseErrorConnect' => 'Errorea datu-basearen zerbitzariarekin konektatzen saiatzean',
	'Installation_DatabaseCheck' => 'Datu-basearen egiaztapena',
	'Installation_DatabaseServerVersion' => 'Datu-basearen zerbitzariaren bertsioa',
	'Installation_DatabaseCreation' => 'Datu-basea sortzea',
	'Installation_LargePiwikInstances' => 'Laguntza Piwik-en instalazio handientzat',
	'Installation_JsTag' => 'JavaScript etiketa',
	'Installation_Congratulations' => 'Zorionak',
	'Installation_CongratulationsHelp' => '<p>Zorionak! Zure Piwik instalazioa osatu da.</p><p>Egiaztatu JavaScript kodea zure orrietan txertatuta dagoela eta ondoren itxaron lehenengo bisitei!</p>',
	'Installation_ContinueToPiwik' => 'Jarraitu Piwik-era',
	'Installation_SetupWebsite' => 'Konfiguratu webgunea',
	'Installation_SetupWebSiteName' => 'webgunearen izena',
	'Installation_SetupWebSiteURL' => 'webgunearen URLa',
	'Installation_SetupWebsiteError' => 'Errorea gertatu da webgunea gehitzean',
	'Installation_SetupWebsiteSetupSuccess' => '%s webgunea ondo sortu da!',
	'Installation_SuperUserLogin' => 'supererabiltzaile-izena',
	'Installation_Password' => 'pasahitza',
	'Installation_PasswordRepeat' => 'pasahitza (errepikatu)',
	'Installation_Email' => 'helbide elektronikoa',
	'Installation_SecurityNewsletter' => 'bidal iezadazu e-posta Piwik-en bertsio-berritze eta segurtasun-alerta nagusienekin',
	'Installation_CommunityNewsletter' => 'bidal iezadazu e-posta komunitateko eguneraketekin (plugin berriak, ezaugarri berriak, ...)',
	'Installation_PasswordDoNotMatch' => 'pasahitzak ez datoz bat',
	'Installation_Requirements' => 'Piwik-en beharrak',
	'Installation_Optional' => 'Aukerazkoa',
	'Installation_Legend' => 'Legenda',
	'Installation_Extension' => 'hedapena',
	'Installation_SystemCheck' => 'Sistemaren egiaztapena',
	'Installation_SystemCheckPhp' => 'PHP bertsioa',
	'Installation_SystemCheckExtensions' => 'Beharrezko bestelako hedapenak',
	'Installation_SystemCheckDatabaseHelp' => 'Piwik-ek mysqli hedapena edo PDO eta pdo_mysql hedapenak behar ditu.',
	'Installation_SystemCheckPdoAndMysqliHelp' => 'Linux zerbitzari batean ondorengo aukerekin konpila dezakezu php:: %1$s    Gehitu ondorengo lerroak zure php.ini fitxategian: %2$s',
	'Installation_SystemCheckPhpPdoAndMysqliSite' => 'Argibide gehiago: <a style="color:red" href="http://php.net/pdo">PHP PDO</a> eta <a style="color:red" href="http://php.net/mysqli">MYSQLI</a>.',
	'Installation_SystemCheckWinPdoAndMysqliHelp' => 'Windows zerbitzari batean ondorengo lerroak gehi ditzakezu zure php.ini fitxategian: %s',
	'Installation_SystemCheckSplHelp' => 'Standard PHP Library (SPL) lehenetsita gaituta duela konfiguratu eta birkonpilatu behar duzu PHP.',
	'Installation_SystemCheckZlibHelp' => '"zlib" gaituta duela konfiguratu eta birkonpilatu behar duzu PHP, --with-zlib aukerarekin.',
	'Installation_SystemCheckIconvHelp' => '"iconv" gaituta duela konfiguratu eta birkonpilatu behar duzu PHP, --with-iconv aukerarekin.',
	'Installation_SystemCheckWriteDirs' => 'Idazteko baimena duten direktorioak',
	'Installation_SystemCheckWriteDirsHelp' => 'Errore hau konpontzeko zure Linux sisteman, saiatu ondorengo komandoa(k) exekutatzen',
	'Installation_SystemCheckMemoryLimit' => 'Memoriaren muga',
	'Installation_SystemCheckMemoryLimitHelp' => 'Trafiko handiko webgune batean, artxibatzeko prozesuak onartutako memoria baino gehiago har lezake. Beharrezkoa bada, aldatu memory_limit direktiba zure php.ini fitxategian.',
	'Installation_SystemCheckOpenURL' => 'Ireki URLa',
	'Installation_SystemCheckOpenURLHelp' => 'Buletinen harpidetzek, eguneraketen jakinarazpenek eta klik bakarreko eguneraketek "curl" hedapena, allow_url_fopen=On edo fsockopen() gaituta egotea behar dute.',
	'Installation_SystemCheckGD' => 'GD > 2.x (grafikak)',
	'Installation_SystemCheckGDHelp' => 'Grafika txikiek ez dute funtzionatuko.',
	'Installation_SystemCheckFunctions' => 'Beharrezko funtzioak',
	'Installation_SystemCheckTimeLimitHelp' => 'Trafiko handiko webgune batean, artxibatzeko prozesuak onartutako denbora baino gehiago har lezake. Beharrezkoa bada, aldatu max_execution_time direktiba zure php.ini fitxategian.',
	'Installation_SystemCheckMailHelp' => 'Erreakzioak eta galdutako pasahitzen mezuak ezingo dira bidali mail() gabe.',
	'Installation_SystemCheckError' => 'Errorea gertatu da - aurrera jarraitu aurretik konpondu behar da',
	'Installation_SystemCheckWarning' => 'Piwik ondo ibiliko da baina zenbait ezaugarri falta litezke',
	'Installation_Tables' => 'Taulak sortzen',
	'Installation_TablesWithSameNamesFound' => 'Zure %1$s datu-baseko zenbait taulek %2$s Piwik sortzen saiatzen ari den taulen izen berak dituzte',
	'Installation_TablesFound' => 'Ondorengo taulak aurkitu dira datu-basean',
	'Installation_TablesWarningHelp' => 'Aukeratu dagoen datu-baseko taulak berrerabiltzea edo hautatu instalazio garbia dauden datuak datu-basetik ezabatzeko.',
	'Installation_TablesReuse' => 'Berrerabili dauden taulak',
	'Installation_TablesDelete' => 'Ezabatu atzemandako taulak',
	'Installation_TablesDeletedSuccess' => 'Aurretik zeuden Piwik taulak ondo ezabatu dira',
	'Installation_TablesCreatedSuccess' => 'Taulak ondo sortu dira!',
	'Installation_DatabaseCreatedSuccess' => '%s datu-basea ondo sortu da!',
	'Installation_GoBackAndDefinePrefix' => 'Zoaz atzera eta definitu aurrizki bat Piwik-en taulentzat',
	'Installation_ConfirmDeleteExistingTables' => 'Ziur zaude ondorengo taulak: %s datu-basetik ezabatu nahi dituzula? OHARRA: TAULA HAUETAKO DATUAK EZINGO DIRA BERRESKURATU!',
	'Installation_Welcome' => 'Ongi etorri!',
	'Installation_WelcomeHelp' => '<p>Piwik kode irekiko web analitiken softwarea da, zure bisitariengandik nahi duzun informazioa erraz eskuratzeko.</p><p>Prozesu hau %s urrats errazetan dago banatuta eta bost minutu inguru hartuko ditu.</p>',
	'Installation_ErrorInvalidState' => 'Errorea: badirudi instalazio prozesuko urrats bat saltatu nahi duzula edo zure cookie-ak desgaituta daudela edo Piwik konfigurazio-fitxategia dagoeneko sortuta dagoela. %1$sZiurtatu zure cookie-ak gaituta daudela%2$s eta zoaz atzera %3$s instalazioaren lehenengo orrira %4$s.',
	'Live_VisitorLog' => 'Bisitariaren loga',
	'Live_Time' => 'Ordua',
	'Live_Referrer_URL' => 'URL erreferentea',
	'Login_LoginPasswordNotCorrect' => 'Erabiltzaile-izena eta pasahitza ez datoz bat',
	'Login_Password' => 'Pasahitza',
	'Login_PasswordRepeat' => 'Pasahitza (errepikatu)',
	'Login_ChangePassword' => 'Aldatu pasahitza',
	'Login_LoginOrEmail' => 'Erabiltzaile-izena edo e-posta',
	'Login_LogIn' => 'Hasi saioa',
	'Login_Logout' => 'Amaitu saioa',
	'Login_LostYourPassword' => 'Pasahitza galdu duzu?',
	'Login_PasswordsDoNotMatch' => 'Pasahitzak ez datoz bat.',
	'Login_InvalidUsernameEmail' => 'Erabiltzaile-izen edo helbide elektroniko baliogabea',
	'Login_InvalidOrExpiredToken' => 'Tokena baliogabea da edo iraungi egin da',
	'Login_ContactAdmin' => 'Arrazoi posiblea: zure ostalariak mail() funtzioa ezgaituta izan dezake.<br />Jar zaitez harremanetan zure Piwik kudeatzailearekin.',
	'Provider_WidgetProviders' => 'Hornitzaileak',
	'Provider_ColumnProvider' => 'Hornitzailea',
	'Provider_SubmenuLocationsProvider' => 'Kokalekuak eta hornitzailea',
	'Referers_Referers' => 'Erreferenteak',
	'Referers_SearchEngines' => 'Bilaketa-motorrak',
	'Referers_Keywords' => 'Gako-hitzak',
	'Referers_DirectEntry' => 'Sarrera zuzena',
	'Referers_Websites' => 'Webguneak',
	'Referers_Campaigns' => 'Kanpainak',
	'Referers_Evolution' => 'Bilakaera periodoan zehar',
	'Referers_Type' => 'Erreferente mota',
	'Referers_ColumnRefererType' => 'Erreferente mota',
	'Referers_ColumnSearchEngine' => 'Bilaketa-motorra',
	'Referers_ColumnWebsite' => 'Webgunea',
	'Referers_ColumnWebsitePage' => 'Webguneko orria',
	'Referers_ColumnKeyword' => 'Gako-hitza',
	'Referers_ColumnCampaign' => 'Kanpaina',
	'Referers_DetailsByRefererType' => 'Xehetasunak erreferente motako',
	'Referers_TypeDirectEntries' => '%s sarbide zuzen',
	'Referers_TypeSearchEngines' => '%s bilaketa-motorretatik',
	'Referers_TypeWebsites' => '%s webguneetatik',
	'Referers_TypeCampaigns' => '%s kanpainetatik',
	'Referers_Distinct' => 'Erreferente desberdinak erreferente motagatik',
	'Referers_DistinctSearchEngines' => 'bilaketa-motor desberdin',
	'Referers_DistinctKeywords' => 'gako-hitz desberdin',
	'Referers_DistinctCampaigns' => 'kanpaina desberdin',
	'Referers_DistinctWebsites' => 'webgune desberdin',
	'Referers_SubmenuSearchEngines' => 'Bilaketa-motorrak eta gako-hitzak',
	'Referers_SubmenuWebsites' => 'Webguneak',
	'Referers_SubmenuCampaigns' => 'Kanpainak',
	'Referers_WidgetKeywords' => 'Gako-hitzen zerrenda',
	'Referers_WidgetCampaigns' => 'Kanpainen zerrenda',
	'Referers_WidgetExternalWebsites' => 'Kanpoko webguneen zerrenda',
	'Referers_WidgetSearchEngines' => 'Gehien erabilitako bilaketa-motorrak',
	'Referers_WidgetOverview' => 'Orokorra',
	'SecurityInfo_PluginDescription' => 'PHP Security Consortium-en PhpSecInfo-n oinarrituta, plugin honen zure PHP ingurunearen segurtasun-informazioa ematen du eta hobekuntzak egiteko gomendioak ematen ditu. Hainbat geruzetan oinarritutako hurbilpena darabilen segurtasun tresna da. Ez ditu garapen-praktika seguruak edo kodearen/aplikazioaren auditoriak ordezkatzen.',
	'SecurityInfo_Security' => 'Segurtasuna',
	'SecurityInfo_SecurityInformation' => 'PHP segurtasun-informazioa',
	'SecurityInfo_Test' => 'Probatu',
	'SecurityInfo_Result' => 'Emaitza',
	'SitesManager_Sites' => 'Webguneak',
	'SitesManager_WebsitesManagement' => 'Webguneen kudeaketa',
	'SitesManager_MainDescription' => 'Zure web analitiken txostenek webguneak behar dituzte! Gehitu, eguneratu, ezabatu webguneak eta erakutsi zure orrietan txertatu beharreko JavaScript kodea.',
	'SitesManager_JsTrackingTag' => 'JavaScript jarraipen-etiketa',
	'SitesManager_JsTrackingTagHelp' => 'Hemen da zure orri guztietan txertatu beharreko JavaScript jarraipen-etiketa',
	'SitesManager_ShowTrackingTag' => 'erakutsi jarraipen-etiketa',
	'SitesManager_NoWebsites' => 'Ez daukazu kudeatzeko webgunerik.',
	'SitesManager_AddSite' => 'Gehitu webgune berria',
	'SitesManager_AliasUrlHelp' => 'Gomendagarria da, baina ez beharrezkoa, bisitariek webgune hau atzitzeko erabiltzen dituzten URL ezberdinak zehaztea.     Webgune baterako alias URLak ez dira agertuko Erreferenteak > Webguneak txostenean.     Konturatu ez dela beharrezkoa URLak \'www\'-rekin edo gabe zehaztea, Piwik-ek automatikoki biak hartzen baititu kontuan.',
	'SitesManager_Urls' => 'URLak',
	'SitesManager_MenuSites' => 'Webguneak',
	'SitesManager_DeleteConfirm_js' => 'Ziur zaude %s webgunea ezabatu nahi duzula?',
	'SitesManager_ExceptionDeleteSite' => 'Ezin da webgune hau ezabatu erregistratutako bakarra delako. Gehitu webgune berri bat lehenik eta ezabatu hau ondoren.',
	'SitesManager_ExceptionNoUrl' => 'Webgunearentzat URL bat zehaztu behar duzu gutxienez.',
	'SitesManager_ExceptionEmptyName' => 'Webgunearen izenak ezin du hutsa izan.',
	'SitesManager_ExceptionInvalidUrl' => '\'%s\' URLa ez da baliozko URL bat.',
	'TranslationsAdmin_MenuTranslations' => 'Itzulpenak',
	'TranslationsAdmin_MenuLanguages' => 'Hizkuntzak',
	'TranslationsAdmin_LanguageCode' => 'Hizkuntza-kodea',
	'TranslationsAdmin_Plugin' => 'Plugina',
	'TranslationsAdmin_Definition' => 'Definizioa',
	'TranslationsAdmin_DefaultString' => 'Lehenetsitako katea (Ingelesa)',
	'TranslationsAdmin_TranslationString' => 'Itzulitako katea (uneko hizkuntza: %s)',
	'TranslationsAdmin_Translations' => 'Itzulpenak',
	'TranslationsAdmin_FixPermissions' => 'Mesedez konpondu fitxategi-sistemaren baimenak',
	'TranslationsAdmin_AddLanguage' => 'Gehitu hizkuntza',
	'TranslationsAdmin_Export' => 'Esportatu hizkuntza',
	'TranslationsAdmin_Import' => 'Inportatu hizkuntza',
	'UserCountry_Country' => 'Herrialdea',
	'UserCountry_Continent' => 'Kontinentea',
	'UserCountry_DistinctCountries' => '%s herrialde desberdin',
	'UserCountry_SubmenuLocations' => 'Kokalekuak',
	'UserCountry_country_ac' => 'Ascension uharteak',
	'UserCountry_country_ad' => 'Andorra',
	'UserCountry_country_ae' => 'Arabiar Emirerri Batuak',
	'UserCountry_country_af' => 'Afghanistan',
	'UserCountry_country_ag' => 'Antigua eta Barbuda',
	'UserCountry_country_ai' => 'Anguilla',
	'UserCountry_country_al' => 'Albania',
	'UserCountry_country_am' => 'Armenia',
	'UserCountry_country_an' => 'Holandarren Antillak',
	'UserCountry_country_ao' => 'Angola',
	'UserCountry_country_aq' => 'Antartika',
	'UserCountry_country_ar' => 'Argentina',
	'UserCountry_country_as' => 'Samoa amerikarra',
	'UserCountry_country_at' => 'Austria',
	'UserCountry_country_au' => 'Australia',
	'UserCountry_country_aw' => 'Aruba',
	'UserCountry_country_ax' => 'Aland uharteak',
	'UserCountry_country_az' => 'Azerbaijan',
	'UserCountry_country_ba' => 'Bosnia-Herzegovina',
	'UserCountry_country_bb' => 'Barbados',
	'UserCountry_country_bd' => 'Bangladesh',
	'UserCountry_country_be' => 'Belgika',
	'UserCountry_country_bf' => 'Burkina Faso',
	'UserCountry_country_bg' => 'Bulgaria',
	'UserCountry_country_bh' => 'Bahrain',
	'UserCountry_country_bi' => 'Burundi',
	'UserCountry_country_bj' => 'Benin',
	'UserCountry_country_bl' => 'Saint Barthelemy',
	'UserCountry_country_bm' => 'Bermuda',
	'UserCountry_country_bn' => 'Bruneo',
	'UserCountry_country_bo' => 'Bolivia',
	'UserCountry_country_br' => 'Brasil',
	'UserCountry_country_bs' => 'Bahamak',
	'UserCountry_country_bt' => 'Bhutan',
	'UserCountry_country_bu' => 'Burma',
	'UserCountry_country_bv' => 'Bouvet uhartea',
	'UserCountry_country_bw' => 'Botswana',
	'UserCountry_country_by' => 'Bielorrusia',
	'UserCountry_country_bz' => 'Belize',
	'UserCountry_country_ca' => 'Kanada',
	'UserCountry_country_cc' => 'Cocos (Keeling) uharteak',
	'UserCountry_country_cd' => 'Kongo',
	'UserCountry_country_cf' => 'Afrika Erdiko Errepublika',
	'UserCountry_country_cg' => 'Kongo',
	'UserCountry_country_ch' => 'Suitza',
	'UserCountry_country_ci' => 'Boli Kosta',
	'UserCountry_country_ck' => 'Cook uharteak',
	'UserCountry_country_cl' => 'Txile',
	'UserCountry_country_cm' => 'Kamerun',
	'UserCountry_country_cn' => 'Txina',
	'UserCountry_country_co' => 'Kolonbia',
	'UserCountry_country_cp' => 'Clipperton uhartea',
	'UserCountry_country_cr' => 'Costa Rica',
	'UserCountry_country_cs' => 'Serbia Montenegro',
	'UserCountry_country_cu' => 'Kuba',
	'UserCountry_country_cv' => 'Cabo Verde',
	'UserCountry_country_cx' => 'Christmas uhartea',
	'UserCountry_country_cy' => 'Zipre',
	'UserCountry_country_cz' => 'Txekia',
	'UserCountry_country_de' => 'Alemania',
	'UserCountry_country_dg' => 'Diego Garcia',
	'UserCountry_country_dj' => 'Djibuti',
	'UserCountry_country_dk' => 'Danimarka',
	'UserCountry_country_dm' => 'Dominika',
	'UserCountry_country_do' => 'Dominikar Errepublika',
	'UserCountry_country_dz' => 'Aljeria',
	'UserCountry_country_ea' => 'Ceuta, Melilla',
	'UserCountry_country_ec' => 'Ekuador',
	'UserCountry_country_ee' => 'Estonia',
	'UserCountry_country_eg' => 'Egipto',
	'UserCountry_country_eh' => 'Mendebaldeko Sahara',
	'UserCountry_country_er' => 'Eritrea',
	'UserCountry_country_es' => 'Espainia',
	'UserCountry_country_et' => 'Etiopia',
	'UserCountry_country_eu' => 'Europar Batasuna',
	'UserCountry_country_fi' => 'Finlandia',
	'UserCountry_country_fj' => 'Fiji',
	'UserCountry_country_fk' => 'Falkland uharteak (Malvinak)',
	'UserCountry_country_fm' => 'Mikronesia',
	'UserCountry_country_fo' => 'Faroe uharteak',
	'UserCountry_country_fr' => 'Frantzia',
	'UserCountry_country_fx' => 'Frantzia, Metropolia',
	'UserCountry_country_ga' => 'Gabon',
	'UserCountry_country_gb' => 'Britainia Handia',
	'UserCountry_country_gd' => 'Grenada',
	'UserCountry_country_ge' => 'Georgia',
	'UserCountry_country_gf' => 'Guyana Frantsesa',
	'UserCountry_country_gg' => 'Guernsey',
	'UserCountry_country_gh' => 'Ghana',
	'UserCountry_country_gi' => 'Gibraltar',
	'UserCountry_country_gl' => 'Groenlandia',
	'UserCountry_country_gm' => 'Gambia',
	'UserCountry_country_gn' => 'Ginea',
	'UserCountry_country_gp' => 'Guadalupe',
	'UserCountry_country_gq' => 'Ekuatore Ginea',
	'UserCountry_country_gr' => 'Grezia',
	'UserCountry_country_gs' => 'Hegoaldeko Georgia eta Hegoaldeko Sandwich uharteak',
	'UserCountry_country_gt' => 'Guatemala',
	'UserCountry_country_gu' => 'Guam',
	'UserCountry_country_gw' => 'Ginea Bissau',
	'UserCountry_country_gy' => 'Guyana',
	'UserCountry_country_hk' => 'Hong Kong',
	'UserCountry_country_hm' => 'Heard eta McDonald uharteak',
	'UserCountry_country_hn' => 'Honduras',
	'UserCountry_country_hr' => 'Kroazia',
	'UserCountry_country_ht' => 'Haiti',
	'UserCountry_country_hu' => 'Hungaria',
	'UserCountry_country_ic' => 'Kanariar uharteak',
	'UserCountry_country_id' => 'Indonesia',
	'UserCountry_country_ie' => 'Irlanda',
	'UserCountry_country_il' => 'Israel',
	'UserCountry_country_im' => 'Man uhartea',
	'UserCountry_country_in' => 'India',
	'UserCountry_country_io' => 'British Indian Ocean Territory',
	'UserCountry_country_iq' => 'Irak',
	'UserCountry_country_ir' => 'Iran',
	'UserCountry_country_is' => 'Islandia',
	'UserCountry_country_it' => 'Italia',
	'UserCountry_country_je' => 'Jersey',
	'UserCountry_country_jm' => 'Jamaika',
	'UserCountry_country_jo' => 'Jordan',
	'UserCountry_country_jp' => 'Japonia',
	'UserCountry_country_ke' => 'Kenia',
	'UserCountry_country_kg' => 'Kirgizistan',
	'UserCountry_country_kh' => 'Kanbodia',
	'UserCountry_country_ki' => 'Kiribati',
	'UserCountry_country_km' => 'Komoreak',
	'UserCountry_country_kn' => 'Saint Kitts eta Nevis',
	'UserCountry_country_kp' => 'Korea',
	'UserCountry_country_kr' => 'Korea',
	'UserCountry_country_kw' => 'Kuwait',
	'UserCountry_country_ky' => 'Cayman uharteak',
	'UserCountry_country_kz' => 'Kazakhstan',
	'UserCountry_country_la' => 'Laos',
	'UserCountry_country_lb' => 'Libano',
	'UserCountry_country_lc' => 'Santa Luzia',
	'UserCountry_country_li' => 'Liechtestein',
	'UserCountry_country_lk' => 'Sri Lanka',
	'UserCountry_country_lr' => 'Liberia',
	'UserCountry_country_ls' => 'Lesotho',
	'UserCountry_country_lt' => 'Lituania',
	'UserCountry_country_lu' => 'Luxenburgo',
	'UserCountry_country_lv' => 'Letonia',
	'UserCountry_country_ly' => 'Libia',
	'UserCountry_country_ma' => 'Maroko',
	'UserCountry_country_mc' => 'Monako',
	'UserCountry_country_md' => 'Moldavia',
	'UserCountry_country_me' => 'Montenegro',
	'UserCountry_country_mf' => 'Saint Martin',
	'UserCountry_country_mg' => 'Madagaskar',
	'UserCountry_country_mh' => 'Marshall Uharteak',
	'UserCountry_country_mk' => 'Mazedonia',
	'UserCountry_country_ml' => 'Mali',
	'UserCountry_country_mm' => 'Myanmar',
	'UserCountry_country_mn' => 'Mongolia',
	'UserCountry_country_mo' => 'Macau',
	'UserCountry_country_mp' => 'Northern Mariana Islands',
	'UserCountry_country_mq' => 'Martinika',
	'UserCountry_country_mr' => 'Mauritania',
	'UserCountry_country_ms' => 'Montserrat',
	'UserCountry_country_mt' => 'Malta',
	'UserCountry_country_mu' => 'Maurizio',
	'UserCountry_country_mv' => 'Maldivak',
	'UserCountry_country_mw' => 'Malawi',
	'UserCountry_country_mx' => 'Mexiko',
	'UserCountry_country_my' => 'Malaysia',
	'UserCountry_country_mz' => 'Mozambike',
	'UserCountry_country_na' => 'Namibia',
	'UserCountry_country_nc' => 'Kaledonia Berria',
	'UserCountry_country_ne' => 'Niger',
	'UserCountry_country_nf' => 'Norfolk uhartea',
	'UserCountry_country_ng' => 'Nigeria',
	'UserCountry_country_ni' => 'Nikaragua',
	'UserCountry_country_nl' => 'Herbehereak',
	'UserCountry_country_no' => 'Norbegia',
	'UserCountry_country_np' => 'Nepal',
	'UserCountry_country_nr' => 'Nauru',
	'UserCountry_country_nt' => 'Eremu Neutroa',
	'UserCountry_country_nu' => 'Niue',
	'UserCountry_country_nz' => 'Zeelanda Berria',
	'UserCountry_country_om' => 'Oman',
	'UserCountry_country_pa' => 'Panama',
	'UserCountry_country_pe' => 'Peru',
	'UserCountry_country_pf' => 'Polinesia Frantsesa',
	'UserCountry_country_pg' => 'Papua Ginea Berria',
	'UserCountry_country_ph' => 'Filipinak',
	'UserCountry_country_pk' => 'Pakistan',
	'UserCountry_country_pl' => 'Polonia',
	'UserCountry_country_pm' => 'Saint-Pierre eta Mikelune',
	'UserCountry_country_pn' => 'Pitcairn',
	'UserCountry_country_pr' => 'Puerto Rico',
	'UserCountry_country_ps' => 'Palestinako lurralde okupatua',
	'UserCountry_country_pt' => 'Portugal',
	'UserCountry_country_pw' => 'Palau',
	'UserCountry_country_py' => 'Paraguai',
	'UserCountry_country_qa' => 'Qatar',
	'UserCountry_country_re' => 'Reunion',
	'UserCountry_country_ro' => 'Errumania',
	'UserCountry_country_rs' => 'Serbia',
	'UserCountry_country_ru' => 'Errusia',
	'UserCountry_country_rw' => 'Ruanda',
	'UserCountry_country_sa' => 'Saudi Arabia',
	'UserCountry_country_sb' => 'Solomon Uharteak',
	'UserCountry_country_sc' => 'Seychelleak',
	'UserCountry_country_sd' => 'Sudan',
	'UserCountry_country_se' => 'Suedia',
	'UserCountry_country_sf' => 'Finlandia',
	'UserCountry_country_sg' => 'Singapur',
	'UserCountry_country_sh' => 'Santa Helena',
	'UserCountry_country_si' => 'Eslovenia',
	'UserCountry_country_sj' => 'Svalbard',
	'UserCountry_country_sk' => 'Eslovakia',
	'UserCountry_country_sl' => 'Sierra Leona',
	'UserCountry_country_sm' => 'San Marino',
	'UserCountry_country_sn' => 'Senegal',
	'UserCountry_country_so' => 'Somalia',
	'UserCountry_country_sr' => 'Surinam',
	'UserCountry_country_st' => 'Sao Tome eta Principe',
	'UserCountry_country_su' => 'Old U.S.S.R',
	'UserCountry_country_sv' => 'El Salvador',
	'UserCountry_country_sy' => 'Siria',
	'UserCountry_country_sz' => 'Swazilandia',
	'UserCountry_country_ta' => 'Tristan da Cunha',
	'UserCountry_country_tc' => 'Turks eta Caico uharteak',
	'UserCountry_country_td' => 'Txad',
	'UserCountry_country_tf' => 'Hegoaldeko lurralde frantsesak',
	'UserCountry_country_tg' => 'Togo',
	'UserCountry_country_th' => 'Thailandia',
	'UserCountry_country_tj' => 'Tajikistan',
	'UserCountry_country_tk' => 'Tokelau',
	'UserCountry_country_tl' => 'Ekialdeko Timor',
	'UserCountry_country_tm' => 'Turkmenistan',
	'UserCountry_country_tn' => 'Tunisia',
	'UserCountry_country_to' => 'Tonga',
	'UserCountry_country_tp' => 'Ekialdeko Timor',
	'UserCountry_country_tr' => 'Turkia',
	'UserCountry_country_tt' => 'Trinidad eta Tobago',
	'UserCountry_country_tv' => 'Tuvalu',
	'UserCountry_country_tw' => 'Taiwan',
	'UserCountry_country_tz' => 'Tanzania',
	'UserCountry_country_ua' => 'Ukraina',
	'UserCountry_country_ug' => 'Uganda',
	'UserCountry_country_uk' => 'Erresuma Batua',
	'UserCountry_country_um' => 'Estatu Batuetako kanpoaldeko uharte txikiak',
	'UserCountry_country_us' => 'Ameriketako Estatu Batuak',
	'UserCountry_country_uy' => 'Uruguai',
	'UserCountry_country_uz' => 'Uzbekistan',
	'UserCountry_country_va' => 'Vatikanoa',
	'UserCountry_country_vc' => 'Saint Vincent eta Granadinak',
	'UserCountry_country_ve' => 'Venezuela',
	'UserCountry_country_vg' => 'Birjina uharteak (britainiarrak)',
	'UserCountry_country_vi' => 'Birjina uharteak (amerikarrak)',
	'UserCountry_country_vn' => 'Vietnam',
	'UserCountry_country_vu' => 'Vanuatu',
	'UserCountry_country_wf' => 'Wallis eta Futuna',
	'UserCountry_country_ws' => 'Samoa',
	'UserCountry_country_ye' => 'Yemen',
	'UserCountry_country_yt' => 'Mayotte',
	'UserCountry_country_yu' => 'Yugoslavia',
	'UserCountry_country_za' => 'Hegoafrika',
	'UserCountry_country_zm' => 'Zambia',
	'UserCountry_country_zr' => 'Zaire',
	'UserCountry_country_zw' => 'Zimbabwe',
	'UserCountry_continent_eur' => 'Europa',
	'UserCountry_continent_afr' => 'Afrika',
	'UserCountry_continent_asi' => 'Asia',
	'UserCountry_continent_amn' => 'Iparramerika',
	'UserCountry_continent_ams' => 'Hegoamerika eta ertamerika',
	'UserCountry_continent_oce' => 'Ozeania',
	'UserSettings_VisitorSettings' => 'Bisitariaren ezarpenak',
	'UserSettings_BrowserFamilies' => 'Nabigatzaile-familiak',
	'UserSettings_Browsers' => 'Nabigatzaileak',
	'UserSettings_Plugins' => 'Pluginak',
	'UserSettings_Configurations' => 'Konfigurazioak',
	'UserSettings_OperatingSystems' => 'Sistema eragileak',
	'UserSettings_Resolutions' => 'Bereizmenak',
	'UserSettings_WideScreen' => 'Pantaila panoramikoa',
	'UserSettings_ColumnBrowserFamily' => 'Nabigatzaile-familia',
	'UserSettings_ColumnBrowser' => 'Nabigatzailea',
	'UserSettings_ColumnPlugin' => 'Plugina',
	'UserSettings_ColumnConfiguration' => 'Konfigurazioa',
	'UserSettings_ColumnOperatingSystem' => 'Sistema eragilea',
	'UserSettings_ColumnResolution' => 'Bereizmena',
	'UserSettings_ColumnTypeOfScreen' => 'Pantaila mota',
	'UserSettings_WidgetResolutions' => 'Pantailaren bereizmenak',
	'UserSettings_WidgetBrowsers' => 'Bisitarien nabigatzaileak',
	'UserSettings_WidgetPlugins' => 'Pluginen zerrenda',
	'UserSettings_WidgetWidescreen' => 'Normala / Panoramikoa',
	'UserSettings_WidgetBrowserFamilies' => 'Nabigatzaileak familiaka',
	'UserSettings_WidgetOperatingSystems' => 'Sistema eragileak',
	'UserSettings_WidgetGlobalVisitors' => 'Bisitarien konfigurazioa',
	'UserSettings_SubmenuSettings' => 'Ezarpenak',
	'UsersManager_UsersManagement' => 'Erabiltzaileen kudeaketa',
	'UsersManager_UsersManagementMainDescription' => 'Sortu erabiltzaile berriak edo eguneratu daudenak. Ondoren hauen baimenak goian ezar ditzakezu.',
	'UsersManager_ManageAccess' => 'Kudeatu atzipena',
	'UsersManager_MainDescription' => 'Erabaki zein erabiltzailek atzi dezaketen Piwik zure webguneetan. Webgune guztietarako baimenak ere ezar ditzakezu ekintza bakarrean.',
	'UsersManager_Sites' => 'Webguneak',
	'UsersManager_AllWebsites' => 'Webgune guztiak',
	'UsersManager_ApplyToAllWebsites' => 'Aplikatu webgune guztiei',
	'UsersManager_User' => 'Erabiltzailea',
	'UsersManager_PrivNone' => 'Atzipenik ez',
	'UsersManager_PrivView' => 'Ikusi',
	'UsersManager_PrivAdmin' => 'Kudeatu',
	'UsersManager_ChangeAllConfirm' => 'Ziur zaude \'%s\'(r)en baimenak aldatu nahi dituzula webgune guztietan?',
	'UsersManager_Password' => 'Pasahitza',
	'UsersManager_Email' => 'E-posta',
	'UsersManager_Alias' => 'Alias',
	'UsersManager_Edit' => 'Editatu',
	'UsersManager_AddUser' => 'Gehitu erabiltzaile berria',
	'UsersManager_MenuUsers' => 'Erabiltzaileak',
	'UsersManager_DeleteConfirm_js' => 'Ziur zaude %s erabiltzailea ezabatu nahi duzula?',
	'UsersManager_ExceptionLoginExists' => '\'%s\' erabiltzaile-izena badago.',
	'UsersManager_ExceptionEmailExists' => '\'%s\' helbide elektronikoa duen erabiltzailea badago.',
	'UsersManager_ExceptionInvalidLoginFormat' => 'Erabiltzaile-izenak %1$s eta %2$s karaktere artekoa izan behar du luzeran eta letrak, zenbakiak edo \'_\' edo \'-\' edo \'.\' karaktereak izan ditzake soilik.',
	'UsersManager_ExceptionInvalidEmail' => 'Helbide elektronikoaren formatua baliogabea da.',
	'UsersManager_ExceptionDeleteDoesNotExist' => '\'%s\' erabiltzailea ez dago beraz ezin da ezabatu.',
	'UsersManager_ExceptionAdminAnonymous' => 'Ezin diozu \'admin\' atzipena eman \'anonymous\' erabiltzaileari.',
	'UsersManager_ExceptionEditAnonymous' => 'anonymous erabiltzailea ezin da editatu edo ezabatu. Saioa hasi gabeko erabiltzaileak definitzeko erabiltzen du Piwik-ek. Adibidez, estatistikak publiko egiteko \'ikusi\' atzipena eman besterik ez duzu \'anonymous\' erabiltzailearentzat.',
	'UsersManager_ExceptionSuperUser' => 'Eskatutako erabiltzailea Superrerabiltzailea da eta ezin zaizkio galderak egin, editatu edo ezabatu APIaren bidez. Superrerabiltzailearen xehetasunak eskuz edita ditzakezu zure Piwik konfigurazio-fitxategian.',
	'UsersManager_ExceptionUserDoesNotExist' => '\'%s\' erabiltzailea ez dago.',
	'UsersManager_ExceptionAccessValues' => 'access parametroak ondorengo balioetako bat izan behar du: [ %s ]',
	'VisitFrequency_Evolution' => 'Bilakaera periodoan zehar',
	'VisitFrequency_ColumnReturningVisits' => 'Itzulerako bisitak',
	'VisitFrequency_ColumnActionsByReturningVisits' => 'Itzulerako bisiten ekintzak',
	'VisitFrequency_ColumnBounceRateForReturningVisits' => 'Itzulerako bisiten errebotatze-tasa',
	'VisitFrequency_ReturnVisits' => '%s itzulerako bisita',
	'VisitFrequency_ReturnActions' => '%s ekintza itzulerako bisitek',
	'VisitFrequency_ReturnBounceRate' => '%s itzulerako bisita errebotatu dira (webgunea utzi dute orri bat ikusi ondoren)',
	'VisitFrequency_WidgetOverview' => 'Maiztasunaren ikuspegi orokorra',
	'VisitFrequency_WidgetGraphReturning' => 'Itzulerako bisiten grafikoa',
	'VisitFrequency_SubmenuFrequency' => 'Maiztasuna',
	'VisitorInterest_VisitsPerDuration' => 'Bisitak bisitaren iraupeneko',
	'VisitorInterest_VisitsPerNbOfPages' => 'Bisitak orri kopuruko',
	'VisitorInterest_ColumnVisitDuration' => 'Bisitaren iraupena',
	'VisitorInterest_ColumnPagesPerVisit' => 'Orriak bisitako',
	'VisitorInterest_WidgetLengths' => 'Bisiten iraupena',
	'VisitorInterest_WidgetPages' => 'Orriak bisitako',
	'VisitorInterest_PlusXMin' => '%s min',
	'VisitorInterest_OnePage' => 'orri bat',
	'VisitorInterest_NPages' => '%s orri',
	'VisitsSummary_VisitsSummary' => 'Bisiten laburpena',
	'VisitsSummary_NbVisits' => '%s bisita',
	'VisitsSummary_NbUniqueVisitors' => '%s bisitari desberdin',
	'VisitsSummary_MaxNbActions' => '%s ekintza gehienez bisita batean',
	'VisitsSummary_NbVisitsBounced' => '%s bisita errebotatu dira (webgunea utzi dute orri bat ikusi ondoren)',
	'VisitsSummary_GenerateTime' => '%s segundo orria sortzeko',
	'VisitsSummary_GenerateQueries' => '%s galdera exekutatuta',
	'VisitsSummary_WidgetLastVisits' => 'Azken bisiten grafikoa',
	'VisitsSummary_WidgetVisits' => 'Bisiten ikuspegi orokorra',
	'VisitsSummary_WidgetLastVisitors' => 'Azken bisitari desberdinen grafikoa',
	'VisitsSummary_WidgetOverviewGraph' => 'Ikuspegi orokorra grafikoarekin',
	'VisitsSummary_SubmenuOverview' => 'Orokorra',
	'VisitTime_LocalTime' => 'Ordu lokaleko bisitak',
	'VisitTime_ServerTime' => 'Zerbitzariaren orduko bisitak',
	'VisitTime_ColumnServerTime' => 'Zerbitzariaren ordua',
	'VisitTime_ColumnLocalTime' => 'Ordu lokala',
	'VisitTime_WidgetLocalTime' => 'Ordu lokaleko bisitak',
	'VisitTime_WidgetServerTime' => 'Zerbitzariaren orduko bisitak',
	'VisitTime_SubmenuTimes' => 'Orduak',
	'VisitTime_NHour' => '%sh',
	'UserLanguage_Language_af' => 'afrikaans',
	'UserLanguage_Language_am' => 'amharikera',
	'UserLanguage_Language_ar' => 'arabiera',
	'UserLanguage_Language_as' => 'assamera',
	'UserLanguage_Language_az' => 'azerbaijanera',
	'UserLanguage_Language_be' => 'bielorrusiera',
	'UserLanguage_Language_bg' => 'bulgariera',
	'UserLanguage_Language_bh' => 'bihariera',
	'UserLanguage_Language_bn' => 'bengalera',
	'UserLanguage_Language_br' => 'bretoiera',
	'UserLanguage_Language_bs' => 'bosniera',
	'UserLanguage_Language_ca' => 'katalana',
	'UserLanguage_Language_cs' => 'txekiera',
	'UserLanguage_Language_cy' => 'galesera',
	'UserLanguage_Language_da' => 'daniera',
	'UserLanguage_Language_de' => 'alemanera',
	'UserLanguage_Language_el' => 'greziera',
	'UserLanguage_Language_en' => 'ingelera',
	'UserLanguage_Language_eo' => 'esperantoa',
	'UserLanguage_Language_es' => 'espainiera',
	'UserLanguage_Language_et' => 'estoniera',
	'UserLanguage_Language_eu' => 'euskara',
	'UserLanguage_Language_fa' => 'pertsiera',
	'UserLanguage_Language_fi' => 'finlandiera',
	'UserLanguage_Language_fo' => 'faroera',
	'UserLanguage_Language_fr' => 'frantsesera',
	'UserLanguage_Language_fy' => 'frisiarra',
	'UserLanguage_Language_ga' => 'gaelikoa',
	'UserLanguage_Language_gd' => 'eskoziar gaelikoa',
	'UserLanguage_Language_gl' => 'galegoa',
	'UserLanguage_Language_gn' => 'guaraniera',
	'UserLanguage_Language_gu' => 'gujaratera',
	'UserLanguage_Language_he' => 'hebreera',
	'UserLanguage_Language_hi' => 'hindia',
	'UserLanguage_Language_hr' => 'kroaziera',
	'UserLanguage_Language_hu' => 'hungariera',
	'UserLanguage_Language_hy' => 'armeniera',
	'UserLanguage_Language_ia' => 'interlingua',
	'UserLanguage_Language_id' => 'indonesiera',
	'UserLanguage_Language_ie' => 'interlingue',
	'UserLanguage_Language_is' => 'islandiera',
	'UserLanguage_Language_it' => 'italiera',
	'UserLanguage_Language_ja' => 'japoniera',
	'UserLanguage_Language_jv' => 'javera',
	'UserLanguage_Language_ka' => 'georgiera',
	'UserLanguage_Language_km' => 'khemerera',
	'UserLanguage_Language_kn' => 'kannada',
	'UserLanguage_Language_ko' => 'koreera',
	'UserLanguage_Language_ku' => 'kurduera',
	'UserLanguage_Language_ky' => 'kirgizera',
	'UserLanguage_Language_la' => 'latina',
	'UserLanguage_Language_ln' => 'lingala',
	'UserLanguage_Language_lo' => 'laosera',
	'UserLanguage_Language_lt' => 'lituaniera',
	'UserLanguage_Language_lv' => 'letoniera',
	'UserLanguage_Language_mk' => 'mazedoniera',
	'UserLanguage_Language_ml' => 'malayalamera',
	'UserLanguage_Language_mn' => 'mongoliera',
	'UserLanguage_Language_mr' => 'marathera',
	'UserLanguage_Language_ms' => 'malaysiera',
	'UserLanguage_Language_mt' => 'maltera',
	'UserLanguage_Language_ne' => 'nepalera',
	'UserLanguage_Language_nl' => 'nederlandera',
	'UserLanguage_Language_nn' => 'norvegiera berria',
	'UserLanguage_Language_no' => 'norvegiera',
	'UserLanguage_Language_oc' => 'okzitaniera',
	'UserLanguage_Language_or' => 'oriya',
	'UserLanguage_Language_pa' => 'punjabera',
	'UserLanguage_Language_pl' => 'poloniera',
	'UserLanguage_Language_ps' => 'paxtuera',
	'UserLanguage_Language_pt' => 'portugalera',
	'UserLanguage_Language_ro' => 'errumaniera',
	'UserLanguage_Language_ru' => 'errusiera',
	'UserLanguage_Language_sa' => 'sanskritoa',
	'UserLanguage_Language_sd' => 'sindhia',
	'UserLanguage_Language_si' => 'sinhala',
	'UserLanguage_Language_sk' => 'eslovakiera',
	'UserLanguage_Language_sl' => 'esloveniera',
	'UserLanguage_Language_so' => 'somaliera',
	'UserLanguage_Language_sq' => 'albaniera',
	'UserLanguage_Language_sr' => 'serbiera',
	'UserLanguage_Language_st' => 'sesothoera',
	'UserLanguage_Language_su' => 'sundanera',
	'UserLanguage_Language_sv' => 'suediera',
	'UserLanguage_Language_sw' => 'swahili',
	'UserLanguage_Language_ta' => 'tamilera',
	'UserLanguage_Language_te' => 'telugua',
	'UserLanguage_Language_th' => 'thailandiera',
	'UserLanguage_Language_ti' => 'tigrinya',
	'UserLanguage_Language_tk' => 'turkmeniera',
	'UserLanguage_Language_tl' => 'tagalog',
	'UserLanguage_Language_tr' => 'turkiera',
	'UserLanguage_Language_tw' => 'twia',
	'UserLanguage_Language_ug' => 'uigurrera',
	'UserLanguage_Language_uk' => 'ukrainera',
	'UserLanguage_Language_ur' => 'urdu',
	'UserLanguage_Language_uz' => 'uzbekera',
	'UserLanguage_Language_vi' => 'vietnamera',
	'UserLanguage_Language_xh' => 'xhosa',
	'UserLanguage_Language_yi' => 'yiddishera',
	'UserLanguage_Language_zh' => 'txinera',
	'UserLanguage_Language_zu' => 'zuluera',
);
